==> openshift-model-6.5.0-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterResourceQuotaListFluent<A extends ClusterResourceQuotaListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ClusterResourceQuota item);
  public A setToItems(Integer index,ClusterResourceQuota item);
  public A addToItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public A addAllToItems(Collection<ClusterResourceQuota> items);
  public A removeFromItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public A removeAllFromItems(Collection<ClusterResourceQuota> items);
  public A removeMatchingFromItems(Predicate<ClusterResourceQuotaBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterResourceQuota> getItems();
  public List<ClusterResourceQuota> buildItems();
  public ClusterResourceQuota buildItem(Integer index);
  public ClusterResourceQuota buildFirstItem();
  public ClusterResourceQuota buildLastItem();
  public ClusterResourceQuota buildMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public A withItems(List<ClusterResourceQuota> items);
  public A withItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public Boolean hasItems();
  public ClusterResourceQuotaListFluent.ItemsNested<A> addNewItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> addNewItemLike(ClusterResourceQuota item);
  public ClusterResourceQuotaListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterResourceQuota item);
  public ClusterResourceQuotaListFluent.ItemsNested<A> editItem(Integer index);
  public ClusterResourceQuotaListFluent.ItemsNested<A> editFirstItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> editLastItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ClusterResourceQuotaFluent<ClusterResourceQuotaListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterResourceQuotaListFluent<A extends ClusterResourceQuotaListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ClusterResourceQuota item);
  public A setToItems(int index,ClusterResourceQuota item);
  public A addToItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public A addAllToItems(Collection<ClusterResourceQuota> items);
  public A removeFromItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public A removeAllFromItems(Collection<ClusterResourceQuota> items);
  public A removeMatchingFromItems(Predicate<ClusterResourceQuotaBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterResourceQuota> getItems();
  public List<ClusterResourceQuota> buildItems();
  public ClusterResourceQuota buildItem(int index);
  public ClusterResourceQuota buildFirstItem();
  public ClusterResourceQuota buildLastItem();
  public ClusterResourceQuota buildMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public A withItems(List<ClusterResourceQuota> items);
  public A withItems(io.fabric8.openshift.api.model.ClusterResourceQuota... items);
  public Boolean hasItems();
  public ClusterResourceQuotaListFluent.ItemsNested<A> addNewItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> addNewItemLike(ClusterResourceQuota item);
  public ClusterResourceQuotaListFluent.ItemsNested<A> setNewItemLike(int index,ClusterResourceQuota item);
  public ClusterResourceQuotaListFluent.ItemsNested<A> editItem(int index);
  public ClusterResourceQuotaListFluent.ItemsNested<A> editFirstItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> editLastItem();
  public ClusterResourceQuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterResourceQuotaBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ClusterResourceQuotaFluent<ClusterResourceQuotaListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
